# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_sso_connectors_get200_response_inner import ApiSsoConnectorsGet200ResponseInner

class TestApiSsoConnectorsGet200ResponseInner(unittest.TestCase):
    """ApiSsoConnectorsGet200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSsoConnectorsGet200ResponseInner:
        """Test ApiSsoConnectorsGet200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSsoConnectorsGet200ResponseInner`
        """
        model = ApiSsoConnectorsGet200ResponseInner()
        if include_optional:
            return ApiSsoConnectorsGet200ResponseInner(
                id = '0',
                provider_name = 'OIDC',
                connector_name = '0',
                config = None,
                domains = [
                    ''
                    ],
                branding = py_logto.models._api_sso_connectors_get_200_response_inner_branding._api_sso_connectors_get_200_response_inner_branding(
                    display_name = '', 
                    logo = '', 
                    dark_logo = '', ),
                sync_profile = True,
                created_at = 1.337,
                name = '',
                provider_type = 'oidc',
                provider_logo = '',
                provider_logo_dark = '',
                provider_config = {
                    'key' : {}
                    }
            )
        else:
            return ApiSsoConnectorsGet200ResponseInner(
                id = '0',
                provider_name = 'OIDC',
                connector_name = '0',
                config = None,
                domains = [
                    ''
                    ],
                branding = py_logto.models._api_sso_connectors_get_200_response_inner_branding._api_sso_connectors_get_200_response_inner_branding(
                    display_name = '', 
                    logo = '', 
                    dark_logo = '', ),
                sync_profile = True,
                created_at = 1.337,
                name = '',
                provider_type = 'oidc',
                provider_logo = '',
                provider_logo_dark = '',
        )
        """

    def testApiSsoConnectorsGet200ResponseInner(self):
        """Test ApiSsoConnectorsGet200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_interaction_verification_webauthn_authentication_post200_response import ApiInteractionVerificationWebauthnAuthenticationPost200Response

class TestApiInteractionVerificationWebauthnAuthenticationPost200Response(unittest.TestCase):
    """ApiInteractionVerificationWebauthnAuthenticationPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInteractionVerificationWebauthnAuthenticationPost200Response:
        """Test ApiInteractionVerificationWebauthnAuthenticationPost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInteractionVerificationWebauthnAuthenticationPost200Response`
        """
        model = ApiInteractionVerificationWebauthnAuthenticationPost200Response()
        if include_optional:
            return ApiInteractionVerificationWebauthnAuthenticationPost200Response(
                challenge = '',
                timeout = 1.337,
                rp_id = '',
                allow_credentials = [
                    py_logto.models._api_interaction_verification_webauthn_registration_post_200_response_exclude_credentials_inner._api_interaction_verification_webauthn_registration_post_200_response_excludeCredentials_inner(
                        type = '', 
                        id = '', 
                        transports = [
                            'usb'
                            ], )
                    ],
                user_verification = 'required',
                extensions = py_logto.models._api_interaction_verification_webauthn_registration_post_200_response_extensions._api_interaction_verification_webauthn_registration_post_200_response_extensions(
                    appid = '', 
                    cred_props = True, 
                    hmac_create_secret = True, )
            )
        else:
            return ApiInteractionVerificationWebauthnAuthenticationPost200Response(
                challenge = '',
        )
        """

    def testApiInteractionVerificationWebauthnAuthenticationPost200Response(self):
        """Test ApiInteractionVerificationWebauthnAuthenticationPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from py_logto.models.api_applications_application_id_user_consent_scopes_get200_response_organization_scopes_inner import ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner
from py_logto.models.api_organization_roles_get200_response_inner import ApiOrganizationRolesGet200ResponseInner
from py_logto.models.api_organization_roles_id_patch_request import ApiOrganizationRolesIdPatchRequest
from py_logto.models.api_organization_roles_id_scopes_post_request import ApiOrganizationRolesIdScopesPostRequest
from py_logto.models.api_organization_roles_id_scopes_put_request import ApiOrganizationRolesIdScopesPutRequest
from py_logto.models.api_organization_roles_post_request import ApiOrganizationRolesPostRequest

from py_logto.api_client import ApiClient, RequestSerialized
from py_logto.api_response import ApiResponse
from py_logto.rest import RESTResponseType


class OrganizationRolesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def api_organization_roles_get(
        self,
        q: Optional[StrictStr] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ApiOrganizationRolesGet200ResponseInner]:
        """Get organization roles

        Get organization roles with pagination.

        :param q:
        :type q: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_get_serialize(
            q=q,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiOrganizationRolesGet200ResponseInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_get_with_http_info(
        self,
        q: Optional[StrictStr] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ApiOrganizationRolesGet200ResponseInner]]:
        """Get organization roles

        Get organization roles with pagination.

        :param q:
        :type q: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_get_serialize(
            q=q,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiOrganizationRolesGet200ResponseInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_get_without_preload_content(
        self,
        q: Optional[StrictStr] = None,
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get organization roles

        Get organization roles with pagination.

        :param q:
        :type q: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_get_serialize(
            q=q,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiOrganizationRolesGet200ResponseInner]",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_get_serialize(
        self,
        q,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if q is not None:
            
            _query_params.append(('q', q))
            
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/organization-roles',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_id_delete(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Delete organization role

        Delete organization role by ID.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_id_delete_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Delete organization role

        Delete organization role by ID.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_id_delete_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete organization role

        Delete organization role by ID.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_delete_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_id_delete_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/organization-roles/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_id_get(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner:
        """Get organization role

        Get organization role details by ID.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_id_get_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner]:
        """Get organization role

        Get organization role details by ID.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_id_get_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get organization role

        Get organization role details by ID.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_get_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_id_get_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/organization-roles/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_id_patch(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_patch_request: ApiOrganizationRolesIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner:
        """Update organization role

        Update organization role details by ID with the given data.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_patch_request: (required)
        :type api_organization_roles_id_patch_request: ApiOrganizationRolesIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_patch_serialize(
            id=id,
            api_organization_roles_id_patch_request=api_organization_roles_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_id_patch_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_patch_request: ApiOrganizationRolesIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner]:
        """Update organization role

        Update organization role details by ID with the given data.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_patch_request: (required)
        :type api_organization_roles_id_patch_request: ApiOrganizationRolesIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_patch_serialize(
            id=id,
            api_organization_roles_id_patch_request=api_organization_roles_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_id_patch_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_patch_request: ApiOrganizationRolesIdPatchRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update organization role

        Update organization role details by ID with the given data.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_patch_request: (required)
        :type api_organization_roles_id_patch_request: ApiOrganizationRolesIdPatchRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_patch_serialize(
            id=id,
            api_organization_roles_id_patch_request=api_organization_roles_id_patch_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_id_patch_serialize(
        self,
        id,
        api_organization_roles_id_patch_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_organization_roles_id_patch_request is not None:
            _body_params = api_organization_roles_id_patch_request


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/organization-roles/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_id_scopes_get(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner]:
        """Get organization role scopes

        Get all organization scopes that are assigned to the specified organization role.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_get_serialize(
            id=id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner]",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_id_scopes_get_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner]]:
        """Get organization role scopes

        Get all organization scopes that are assigned to the specified organization role.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_get_serialize(
            id=id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner]",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_id_scopes_get_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        page: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Page number (starts from 1).")] = None,
        page_size: Annotated[Optional[Annotated[int, Field(strict=True, ge=1)]], Field(description="Entries per page.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get organization role scopes

        Get all organization scopes that are assigned to the specified organization role.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param page: Page number (starts from 1).
        :type page: int
        :param page_size: Entries per page.
        :type page_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_get_serialize(
            id=id,
            page=page,
            page_size=page_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner]",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_id_scopes_get_serialize(
        self,
        id,
        page,
        page_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if page_size is not None:
            
            _query_params.append(('page_size', page_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/organization-roles/{id}/scopes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_id_scopes_organization_scope_id_delete(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        organization_scope_id: Annotated[StrictStr, Field(description="The unique identifier of the organization scope.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Remove organization scope

        Remove a organization scope assignment from the specified organization role.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param organization_scope_id: The unique identifier of the organization scope. (required)
        :type organization_scope_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_organization_scope_id_delete_serialize(
            id=id,
            organization_scope_id=organization_scope_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_id_scopes_organization_scope_id_delete_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        organization_scope_id: Annotated[StrictStr, Field(description="The unique identifier of the organization scope.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Remove organization scope

        Remove a organization scope assignment from the specified organization role.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param organization_scope_id: The unique identifier of the organization scope. (required)
        :type organization_scope_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_organization_scope_id_delete_serialize(
            id=id,
            organization_scope_id=organization_scope_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_id_scopes_organization_scope_id_delete_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        organization_scope_id: Annotated[StrictStr, Field(description="The unique identifier of the organization scope.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Remove organization scope

        Remove a organization scope assignment from the specified organization role.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param organization_scope_id: The unique identifier of the organization scope. (required)
        :type organization_scope_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_organization_scope_id_delete_serialize(
            id=id,
            organization_scope_id=organization_scope_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_id_scopes_organization_scope_id_delete_serialize(
        self,
        id,
        organization_scope_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if organization_scope_id is not None:
            _path_params['organizationScopeId'] = organization_scope_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/organization-roles/{id}/scopes/{organizationScopeId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_id_scopes_post(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_scopes_post_request: ApiOrganizationRolesIdScopesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Assign organization scopes to organization role

        Assign organization scopes to the specified organization role

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_scopes_post_request: (required)
        :type api_organization_roles_id_scopes_post_request: ApiOrganizationRolesIdScopesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_post_serialize(
            id=id,
            api_organization_roles_id_scopes_post_request=api_organization_roles_id_scopes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_id_scopes_post_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_scopes_post_request: ApiOrganizationRolesIdScopesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Assign organization scopes to organization role

        Assign organization scopes to the specified organization role

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_scopes_post_request: (required)
        :type api_organization_roles_id_scopes_post_request: ApiOrganizationRolesIdScopesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_post_serialize(
            id=id,
            api_organization_roles_id_scopes_post_request=api_organization_roles_id_scopes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_id_scopes_post_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_scopes_post_request: ApiOrganizationRolesIdScopesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Assign organization scopes to organization role

        Assign organization scopes to the specified organization role

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_scopes_post_request: (required)
        :type api_organization_roles_id_scopes_post_request: ApiOrganizationRolesIdScopesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_post_serialize(
            id=id,
            api_organization_roles_id_scopes_post_request=api_organization_roles_id_scopes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_id_scopes_post_serialize(
        self,
        id,
        api_organization_roles_id_scopes_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_organization_roles_id_scopes_post_request is not None:
            _body_params = api_organization_roles_id_scopes_post_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/organization-roles/{id}/scopes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_id_scopes_put(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_scopes_put_request: ApiOrganizationRolesIdScopesPutRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Replace organization scopes for organization role

        Replace all organization scopes that are assigned to the specified organization role with the given organization scopes. This effectively removes all existing organization scope assignments and replaces them with the new ones.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_scopes_put_request: (required)
        :type api_organization_roles_id_scopes_put_request: ApiOrganizationRolesIdScopesPutRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_put_serialize(
            id=id,
            api_organization_roles_id_scopes_put_request=api_organization_roles_id_scopes_put_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_id_scopes_put_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_scopes_put_request: ApiOrganizationRolesIdScopesPutRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Replace organization scopes for organization role

        Replace all organization scopes that are assigned to the specified organization role with the given organization scopes. This effectively removes all existing organization scope assignments and replaces them with the new ones.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_scopes_put_request: (required)
        :type api_organization_roles_id_scopes_put_request: ApiOrganizationRolesIdScopesPutRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_put_serialize(
            id=id,
            api_organization_roles_id_scopes_put_request=api_organization_roles_id_scopes_put_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_id_scopes_put_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="The unique identifier of the organization role.")],
        api_organization_roles_id_scopes_put_request: ApiOrganizationRolesIdScopesPutRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Replace organization scopes for organization role

        Replace all organization scopes that are assigned to the specified organization role with the given organization scopes. This effectively removes all existing organization scope assignments and replaces them with the new ones.

        :param id: The unique identifier of the organization role. (required)
        :type id: str
        :param api_organization_roles_id_scopes_put_request: (required)
        :type api_organization_roles_id_scopes_put_request: ApiOrganizationRolesIdScopesPutRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_id_scopes_put_serialize(
            id=id,
            api_organization_roles_id_scopes_put_request=api_organization_roles_id_scopes_put_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_id_scopes_put_serialize(
        self,
        id,
        api_organization_roles_id_scopes_put_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_organization_roles_id_scopes_put_request is not None:
            _body_params = api_organization_roles_id_scopes_put_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/organization-roles/{id}/scopes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def api_organization_roles_post(
        self,
        api_organization_roles_post_request: ApiOrganizationRolesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Create an organization role

        Create a new organization role with the given data.

        :param api_organization_roles_post_request: (required)
        :type api_organization_roles_post_request: ApiOrganizationRolesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_post_serialize(
            api_organization_roles_post_request=api_organization_roles_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def api_organization_roles_post_with_http_info(
        self,
        api_organization_roles_post_request: ApiOrganizationRolesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Create an organization role

        Create a new organization role with the given data.

        :param api_organization_roles_post_request: (required)
        :type api_organization_roles_post_request: ApiOrganizationRolesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_post_serialize(
            api_organization_roles_post_request=api_organization_roles_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def api_organization_roles_post_without_preload_content(
        self,
        api_organization_roles_post_request: ApiOrganizationRolesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create an organization role

        Create a new organization role with the given data.

        :param api_organization_roles_post_request: (required)
        :type api_organization_roles_post_request: ApiOrganizationRolesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._api_organization_roles_post_serialize(
            api_organization_roles_post_request=api_organization_roles_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': None,
            '400': None,
            '401': None,
            '403': None,
            '422': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _api_organization_roles_post_serialize(
        self,
        api_organization_roles_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_organization_roles_post_request is not None:
            _body_params = api_organization_roles_post_request



        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/organization-roles',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_exclude_credentials_inner import ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner
from py_logto.models.api_interaction_verification_webauthn_registration_post200_response_extensions import ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions
from typing import Optional, Set
from typing_extensions import Self

class ApiInteractionVerificationWebauthnAuthenticationPost200Response(BaseModel):
    """
    ApiInteractionVerificationWebauthnAuthenticationPost200Response
    """ # noqa: E501
    challenge: StrictStr
    timeout: Optional[Union[StrictFloat, StrictInt]] = None
    rp_id: Optional[StrictStr] = Field(default=None, alias="rpId")
    allow_credentials: Optional[List[ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner]] = Field(default=None, alias="allowCredentials")
    user_verification: Optional[StrictStr] = Field(default=None, alias="userVerification")
    extensions: Optional[ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions] = None
    __properties: ClassVar[List[str]] = ["challenge", "timeout", "rpId", "allowCredentials", "userVerification", "extensions"]

    @field_validator('user_verification')
    def user_verification_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['required', 'preferred', 'discouraged']):
            raise ValueError("must be one of enum values ('required', 'preferred', 'discouraged')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiInteractionVerificationWebauthnAuthenticationPost200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in allow_credentials (list)
        _items = []
        if self.allow_credentials:
            for _item in self.allow_credentials:
                if _item:
                    _items.append(_item.to_dict())
            _dict['allowCredentials'] = _items
        # override the default output from pydantic by calling `to_dict()` of extensions
        if self.extensions:
            _dict['extensions'] = self.extensions.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiInteractionVerificationWebauthnAuthenticationPost200Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "challenge": obj.get("challenge"),
            "timeout": obj.get("timeout"),
            "rpId": obj.get("rpId"),
            "allowCredentials": [ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner.from_dict(_item) for _item in obj["allowCredentials"]] if obj.get("allowCredentials") is not None else None,
            "userVerification": obj.get("userVerification"),
            "extensions": ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions.from_dict(obj["extensions"]) if obj.get("extensions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_configs_jwt_customizer_get200_response_inner_one_of import ApiConfigsJwtCustomizerGet200ResponseInnerOneOf

class TestApiConfigsJwtCustomizerGet200ResponseInnerOneOf(unittest.TestCase):
    """ApiConfigsJwtCustomizerGet200ResponseInnerOneOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiConfigsJwtCustomizerGet200ResponseInnerOneOf:
        """Test ApiConfigsJwtCustomizerGet200ResponseInnerOneOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiConfigsJwtCustomizerGet200ResponseInnerOneOf`
        """
        model = ApiConfigsJwtCustomizerGet200ResponseInnerOneOf()
        if include_optional:
            return ApiConfigsJwtCustomizerGet200ResponseInnerOneOf(
                key = '',
                value = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf(
                    script = '', 
                    environment_variables = {
                        'key' : ''
                        }, 
                    context_sample = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample(
                        user = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user(
                            id = '0', 
                            username = '', 
                            primary_email = '', 
                            primary_phone = '', 
                            name = '', 
                            avatar = '', 
                            custom_data = py_logto.models.custom_data.customData(), 
                            identities = {
                                'key' : py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_identities_value._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_identities_value(
                                    user_id = '', 
                                    details = py_logto.models.details.details(), )
                                }, 
                            last_sign_in_at = 1.337, 
                            created_at = 1.337, 
                            updated_at = 1.337, 
                            profile = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile(
                                family_name = '', 
                                given_name = '', 
                                middle_name = '', 
                                nickname = '', 
                                preferred_username = '', 
                                website = '', 
                                gender = '', 
                                birthdate = '', 
                                zoneinfo = '', 
                                locale = '', 
                                address = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile_address._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile_address(
                                    formatted = '', 
                                    street_address = '', 
                                    locality = '', 
                                    region = '', 
                                    postal_code = '', 
                                    country = '', ), ), 
                            application_id = '', 
                            is_suspended = True, 
                            sso_identities = [
                                py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_sso_identities_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_ssoIdentities_inner(
                                    issuer = '0', 
                                    identity_id = '0', 
                                    detail = py_logto.models.detail.detail(), )
                                ], 
                            mfa_verification_factors = [
                                'Totp'
                                ], 
                            roles = [
                                py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner(
                                    id = '0', 
                                    name = '0', 
                                    description = '0', 
                                    scopes = [
                                        py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner_scopes_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner_scopes_inner(
                                            id = '0', 
                                            name = '0', 
                                            description = '', 
                                            resource_id = '0', 
                                            resource = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner_scopes_inner_resource._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner_scopes_inner_resource(
                                                id = '0', 
                                                name = '0', 
                                                indicator = '0', 
                                                is_default = True, 
                                                access_token_ttl = 1.337, ), )
                                        ], )
                                ], 
                            organizations = [
                                py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_organization_scopes_inner._api_applications__applicationId__user_consent_scopes_get_200_response_organizationScopes_inner(
                                    id = '0', 
                                    name = '0', 
                                    description = '', )
                                ], 
                            organization_roles = [
                                py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_organization_roles_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_organizationRoles_inner(
                                    organization_id = '', 
                                    role_id = '', 
                                    role_name = '', )
                                ], ), ), 
                    token_sample = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_token_sample._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_tokenSample(
                        jti = '', 
                        aud = null, 
                        scope = '', 
                        client_id = '', 
                        account_id = '', 
                        expires_with_session = True, 
                        grant_id = '', 
                        gty = '', 
                        session_uid = '', 
                        sid = '', 
                        kind = '', ), )
            )
        else:
            return ApiConfigsJwtCustomizerGet200ResponseInnerOneOf(
                key = '',
                value = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf(
                    script = '', 
                    environment_variables = {
                        'key' : ''
                        }, 
                    context_sample = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample(
                        user = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user(
                            id = '0', 
                            username = '', 
                            primary_email = '', 
                            primary_phone = '', 
                            name = '', 
                            avatar = '', 
                            custom_data = py_logto.models.custom_data.customData(), 
                            identities = {
                                'key' : py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_identities_value._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_identities_value(
                                    user_id = '', 
                                    details = py_logto.models.details.details(), )
                                }, 
                            last_sign_in_at = 1.337, 
                            created_at = 1.337, 
                            updated_at = 1.337, 
                            profile = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile(
                                family_name = '', 
                                given_name = '', 
                                middle_name = '', 
                                nickname = '', 
                                preferred_username = '', 
                                website = '', 
                                gender = '', 
                                birthdate = '', 
                                zoneinfo = '', 
                                locale = '', 
                                address = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile_address._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile_address(
                                    formatted = '', 
                                    street_address = '', 
                                    locality = '', 
                                    region = '', 
                                    postal_code = '', 
                                    country = '', ), ), 
                            application_id = '', 
                            is_suspended = True, 
                            sso_identities = [
                                py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_sso_identities_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_ssoIdentities_inner(
                                    issuer = '0', 
                                    identity_id = '0', 
                                    detail = py_logto.models.detail.detail(), )
                                ], 
                            mfa_verification_factors = [
                                'Totp'
                                ], 
                            roles = [
                                py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner(
                                    id = '0', 
                                    name = '0', 
                                    description = '0', 
                                    scopes = [
                                        py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner_scopes_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner_scopes_inner(
                                            id = '0', 
                                            name = '0', 
                                            description = '', 
                                            resource_id = '0', 
                                            resource = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner_scopes_inner_resource._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner_scopes_inner_resource(
                                                id = '0', 
                                                name = '0', 
                                                indicator = '0', 
                                                is_default = True, 
                                                access_token_ttl = 1.337, ), )
                                        ], )
                                ], 
                            organizations = [
                                py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_organization_scopes_inner._api_applications__applicationId__user_consent_scopes_get_200_response_organizationScopes_inner(
                                    id = '0', 
                                    name = '0', 
                                    description = '', )
                                ], 
                            organization_roles = [
                                py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_organization_roles_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_organizationRoles_inner(
                                    organization_id = '', 
                                    role_id = '', 
                                    role_name = '', )
                                ], ), ), 
                    token_sample = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_token_sample._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_tokenSample(
                        jti = '', 
                        aud = null, 
                        scope = '', 
                        client_id = '', 
                        account_id = '', 
                        expires_with_session = True, 
                        grant_id = '', 
                        gty = '', 
                        session_uid = '', 
                        sid = '', 
                        kind = '', ), ),
        )
        """

    def testApiConfigsJwtCustomizerGet200ResponseInnerOneOf(self):
        """Test ApiConfigsJwtCustomizerGet200ResponseInnerOneOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.user_assets_api import UserAssetsApi


class TestUserAssetsApi(unittest.TestCase):
    """UserAssetsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserAssetsApi()

    def tearDown(self) -> None:
        pass

    def test_api_user_assets_post(self) -> None:
        """Test case for api_user_assets_post

        Upload asset
        """
        pass

    def test_api_user_assets_service_status_get(self) -> None:
        """Test case for api_user_assets_service_status_get

        Get service status
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_interaction_put_request import ApiInteractionPutRequest

class TestApiInteractionPutRequest(unittest.TestCase):
    """ApiInteractionPutRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiInteractionPutRequest:
        """Test ApiInteractionPutRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiInteractionPutRequest`
        """
        model = ApiInteractionPutRequest()
        if include_optional:
            return ApiInteractionPutRequest(
                event = 'SignIn',
                identifier = None,
                profile = py_logto.models._api_interaction_put_request_profile._api_interaction_put_request_profile(
                    username = 'MqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                    email = 'k@?x!u'K}qz^sEC)lJ*=-jQ+'6`%cClu,k'!'su[..zF6V,V6rEtCO?&28nxs#k8z)\"\\6\\%TMxo:-sWVoim9gs', 
                    phone = '4', 
                    connector_id = '', 
                    password = '', )
            )
        else:
            return ApiInteractionPutRequest(
                event = 'SignIn',
        )
        """

    def testApiInteractionPutRequest(self):
        """Test ApiInteractionPutRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.applications_api import ApplicationsApi


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsApi()

    def tearDown(self) -> None:
        pass

    def test_api_applications_application_id_roles_get(self) -> None:
        """Test case for api_applications_application_id_roles_get

        Get application API resource roles
        """
        pass

    def test_api_applications_application_id_roles_post(self) -> None:
        """Test case for api_applications_application_id_roles_post

        Assign API resource roles to application
        """
        pass

    def test_api_applications_application_id_roles_put(self) -> None:
        """Test case for api_applications_application_id_roles_put

        Update API resource roles for application
        """
        pass

    def test_api_applications_application_id_roles_role_id_delete(self) -> None:
        """Test case for api_applications_application_id_roles_role_id_delete

        Remove a API resource role from application
        """
        pass

    def test_api_applications_application_id_sign_in_experience_get(self) -> None:
        """Test case for api_applications_application_id_sign_in_experience_get

        Get the application level sign-in experience
        """
        pass

    def test_api_applications_application_id_sign_in_experience_put(self) -> None:
        """Test case for api_applications_application_id_sign_in_experience_put

        Update application level sign-in experience
        """
        pass

    def test_api_applications_application_id_user_consent_scopes_get(self) -> None:
        """Test case for api_applications_application_id_user_consent_scopes_get

        List all the user consent scopes of an application.
        """
        pass

    def test_api_applications_application_id_user_consent_scopes_post(self) -> None:
        """Test case for api_applications_application_id_user_consent_scopes_post

        Assign user consent scopes to application.
        """
        pass

    def test_api_applications_application_id_user_consent_scopes_scope_type_scope_id_delete(self) -> None:
        """Test case for api_applications_application_id_user_consent_scopes_scope_type_scope_id_delete

        Remove user consent scope from application.
        """
        pass

    def test_api_applications_get(self) -> None:
        """Test case for api_applications_get

        Get applications
        """
        pass

    def test_api_applications_id_delete(self) -> None:
        """Test case for api_applications_id_delete

        Delete application
        """
        pass

    def test_api_applications_id_get(self) -> None:
        """Test case for api_applications_id_get

        Get application
        """
        pass

    def test_api_applications_id_patch(self) -> None:
        """Test case for api_applications_id_patch

        Update application
        """
        pass

    def test_api_applications_id_protected_app_metadata_custom_domains_domain_delete(self) -> None:
        """Test case for api_applications_id_protected_app_metadata_custom_domains_domain_delete

        Delete a custom domain.
        """
        pass

    def test_api_applications_id_protected_app_metadata_custom_domains_get(self) -> None:
        """Test case for api_applications_id_protected_app_metadata_custom_domains_get

        Get the list of custom domains of the protected application.
        """
        pass

    def test_api_applications_id_protected_app_metadata_custom_domains_post(self) -> None:
        """Test case for api_applications_id_protected_app_metadata_custom_domains_post

        Add a custom domain to the protected application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_get(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_get

        List all the user consented organizations of a application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_organization_id_delete(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_organization_id_delete

        Revoke a user's access to an organization for a application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_post(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_post

        Grant a list of organization access of a user for a application.
        """
        pass

    def test_api_applications_id_users_user_id_consent_organizations_put(self) -> None:
        """Test case for api_applications_id_users_user_id_consent_organizations_put

        Grant a list of organization access of a user for a application.
        """
        pass

    def test_api_applications_post(self) -> None:
        """Test case for api_applications_post

        Create an application
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_applications_get200_response_inner import ApiApplicationsGet200ResponseInner

class TestApiApplicationsGet200ResponseInner(unittest.TestCase):
    """ApiApplicationsGet200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiApplicationsGet200ResponseInner:
        """Test ApiApplicationsGet200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiApplicationsGet200ResponseInner`
        """
        model = ApiApplicationsGet200ResponseInner()
        if include_optional:
            return ApiApplicationsGet200ResponseInner(
                id = '0',
                name = '0',
                secret = '0',
                description = '',
                type = 'Native',
                oidc_client_metadata = py_logto.models._api_applications_get_200_response_inner_oidc_client_metadata._api_applications_get_200_response_inner_oidcClientMetadata(
                    redirect_uris = [
                        null
                        ], 
                    post_logout_redirect_uris = [
                        ''
                        ], 
                    logo_uri = '', ),
                custom_client_metadata = py_logto.models._api_applications_get_200_response_inner_custom_client_metadata._api_applications_get_200_response_inner_customClientMetadata(
                    cors_allowed_origins = [
                        '0'
                        ], 
                    id_token_ttl = 1.337, 
                    refresh_token_ttl = 1.337, 
                    refresh_token_ttl_in_days = 1.337, 
                    always_issue_refresh_token = True, 
                    rotate_refresh_token = True, ),
                protected_app_metadata = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata._api_applications_get_200_response_inner_protectedAppMetadata(
                    host = '', 
                    origin = '', 
                    session_duration = 1.337, 
                    page_rules = [
                        py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_page_rules_inner._api_applications_get_200_response_inner_protectedAppMetadata_pageRules_inner(
                            path = '', )
                        ], 
                    custom_domains = [
                        py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner(
                            domain = '', 
                            status = 'PendingVerification', 
                            error_message = '', 
                            dns_records = [
                                py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_dns_records_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_dnsRecords_inner(
                                    name = '', 
                                    type = '', 
                                    value = '', )
                                ], 
                            cloudflare_data = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData(
                                id = '', 
                                status = '', 
                                ssl = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl(
                                    status = '', 
                                    validation_errors = [
                                        py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl_validation_errors_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl_validation_errors_inner(
                                            message = '', )
                                        ], ), 
                                verification_errors = [
                                    ''
                                    ], ), )
                        ], ),
                is_third_party = True,
                created_at = 1.337
            )
        else:
            return ApiApplicationsGet200ResponseInner(
                id = '0',
                name = '0',
                secret = '0',
                description = '',
                type = 'Native',
                oidc_client_metadata = py_logto.models._api_applications_get_200_response_inner_oidc_client_metadata._api_applications_get_200_response_inner_oidcClientMetadata(
                    redirect_uris = [
                        null
                        ], 
                    post_logout_redirect_uris = [
                        ''
                        ], 
                    logo_uri = '', ),
                custom_client_metadata = py_logto.models._api_applications_get_200_response_inner_custom_client_metadata._api_applications_get_200_response_inner_customClientMetadata(
                    cors_allowed_origins = [
                        '0'
                        ], 
                    id_token_ttl = 1.337, 
                    refresh_token_ttl = 1.337, 
                    refresh_token_ttl_in_days = 1.337, 
                    always_issue_refresh_token = True, 
                    rotate_refresh_token = True, ),
                protected_app_metadata = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata._api_applications_get_200_response_inner_protectedAppMetadata(
                    host = '', 
                    origin = '', 
                    session_duration = 1.337, 
                    page_rules = [
                        py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_page_rules_inner._api_applications_get_200_response_inner_protectedAppMetadata_pageRules_inner(
                            path = '', )
                        ], 
                    custom_domains = [
                        py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner(
                            domain = '', 
                            status = 'PendingVerification', 
                            error_message = '', 
                            dns_records = [
                                py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_dns_records_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_dnsRecords_inner(
                                    name = '', 
                                    type = '', 
                                    value = '', )
                                ], 
                            cloudflare_data = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData(
                                id = '', 
                                status = '', 
                                ssl = py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl(
                                    status = '', 
                                    validation_errors = [
                                        py_logto.models._api_applications_get_200_response_inner_protected_app_metadata_custom_domains_inner_cloudflare_data_ssl_validation_errors_inner._api_applications_get_200_response_inner_protectedAppMetadata_customDomains_inner_cloudflareData_ssl_validation_errors_inner(
                                            message = '', )
                                        ], ), 
                                verification_errors = [
                                    ''
                                    ], ), )
                        ], ),
                is_third_party = True,
                created_at = 1.337,
        )
        """

    def testApiApplicationsGet200ResponseInner(self):
        """Test ApiApplicationsGet200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class ApiAuthnSingleSignOnSamlConnectorIdPostRequest(BaseModel):
    """
    ApiAuthnSingleSignOnSamlConnectorIdPostRequest
    """ # noqa: E501
    relay_state: StrictStr = Field(description="SAML standard parameter that will be transmitted between the identity provider and the service provider. It will be used as the session ID (jti) of the user's Logto authentication session. This API will use this session ID to retrieve the SSO connector authentication session from the database.", alias="RelayState")
    saml_response: StrictStr = Field(description="The SAML assertion response from the identity provider (IdP).", alias="SAMLResponse")
    __properties: ClassVar[List[str]] = ["RelayState", "SAMLResponse"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiAuthnSingleSignOnSamlConnectorIdPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiAuthnSingleSignOnSamlConnectorIdPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "RelayState": obj.get("RelayState"),
            "SAMLResponse": obj.get("SAMLResponse")
        })
        return _obj





# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user_profile_address import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress

class TestApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress(unittest.TestCase):
    """ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress:
        """Test ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress`
        """
        model = ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress()
        if include_optional:
            return ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress(
                formatted = '',
                street_address = '',
                locality = '',
                region = '',
                postal_code = '',
                country = ''
            )
        else:
            return ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress(
        )
        """

    def testApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress(self):
        """Test ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.api.resources_api import ResourcesApi


class TestResourcesApi(unittest.TestCase):
    """ResourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ResourcesApi()

    def tearDown(self) -> None:
        pass

    def test_api_resources_get(self) -> None:
        """Test case for api_resources_get

        Get API resources
        """
        pass

    def test_api_resources_id_delete(self) -> None:
        """Test case for api_resources_id_delete

        Delete API resource
        """
        pass

    def test_api_resources_id_get(self) -> None:
        """Test case for api_resources_id_get

        Get API resource
        """
        pass

    def test_api_resources_id_is_default_patch(self) -> None:
        """Test case for api_resources_id_is_default_patch

        Set API resource as default
        """
        pass

    def test_api_resources_id_patch(self) -> None:
        """Test case for api_resources_id_patch

        Update API resource
        """
        pass

    def test_api_resources_post(self) -> None:
        """Test case for api_resources_post

        Create an API resource
        """
        pass

    def test_api_resources_resource_id_scopes_get(self) -> None:
        """Test case for api_resources_resource_id_scopes_get

        Get API resource scopes
        """
        pass

    def test_api_resources_resource_id_scopes_post(self) -> None:
        """Test case for api_resources_resource_id_scopes_post

        Create API resource scope
        """
        pass

    def test_api_resources_resource_id_scopes_scope_id_delete(self) -> None:
        """Test case for api_resources_resource_id_scopes_scope_id_delete

        Delete API resource scope
        """
        pass

    def test_api_resources_resource_id_scopes_scope_id_patch(self) -> None:
        """Test case for api_resources_resource_id_scopes_scope_id_patch

        Update API resource scope
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_sign_in_exp_get200_response_password_policy import ApiSignInExpGet200ResponsePasswordPolicy

class TestApiSignInExpGet200ResponsePasswordPolicy(unittest.TestCase):
    """ApiSignInExpGet200ResponsePasswordPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSignInExpGet200ResponsePasswordPolicy:
        """Test ApiSignInExpGet200ResponsePasswordPolicy
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSignInExpGet200ResponsePasswordPolicy`
        """
        model = ApiSignInExpGet200ResponsePasswordPolicy()
        if include_optional:
            return ApiSignInExpGet200ResponsePasswordPolicy(
                length = py_logto.models._api_sign_in_exp_get_200_response_password_policy_length._api_sign_in_exp_get_200_response_passwordPolicy_length(
                    min = 1.337, 
                    max = 1.337, ),
                character_types = py_logto.models._api_sign_in_exp_get_200_response_password_policy_character_types._api_sign_in_exp_get_200_response_passwordPolicy_characterTypes(
                    min = 1.337, ),
                rejects = py_logto.models._api_sign_in_exp_get_200_response_password_policy_rejects._api_sign_in_exp_get_200_response_passwordPolicy_rejects(
                    pwned = True, 
                    repetition_and_sequence = True, 
                    user_info = True, 
                    words = [
                        ''
                        ], )
            )
        else:
            return ApiSignInExpGet200ResponsePasswordPolicy(
        )
        """

    def testApiSignInExpGet200ResponsePasswordPolicy(self):
        """Test ApiSignInExpGet200ResponsePasswordPolicy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Logto API references

    API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

    The version of the OpenAPI document: Cloud
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from py_logto.models.api_configs_jwt_customizer_token_type_path_get200_response_one_of_context_sample_user import ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser

class TestApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser(unittest.TestCase):
    """ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser:
        """Test ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser`
        """
        model = ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser()
        if include_optional:
            return ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser(
                id = '0',
                username = '',
                primary_email = '',
                primary_phone = '',
                name = '',
                avatar = '',
                custom_data = None,
                identities = {
                    'key' : py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_identities_value._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_identities_value(
                        user_id = '', 
                        details = py_logto.models.details.details(), )
                    },
                last_sign_in_at = 1.337,
                created_at = 1.337,
                updated_at = 1.337,
                profile = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile(
                    family_name = '', 
                    given_name = '', 
                    middle_name = '', 
                    nickname = '', 
                    preferred_username = '', 
                    profile = '', 
                    website = '', 
                    gender = '', 
                    birthdate = '', 
                    zoneinfo = '', 
                    locale = '', 
                    address = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_profile_address._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_profile_address(
                        formatted = '', 
                        street_address = '', 
                        locality = '', 
                        region = '', 
                        postal_code = '', 
                        country = '', ), ),
                application_id = '',
                is_suspended = True,
                sso_identities = [
                    py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_sso_identities_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_ssoIdentities_inner(
                        issuer = '0', 
                        identity_id = '0', 
                        detail = py_logto.models.detail.detail(), )
                    ],
                mfa_verification_factors = [
                    'Totp'
                    ],
                roles = [
                    py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner(
                        id = '0', 
                        name = '0', 
                        description = '0', 
                        scopes = [
                            py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner_scopes_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner_scopes_inner(
                                id = '0', 
                                name = '0', 
                                description = '', 
                                resource_id = '0', 
                                resource = py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_roles_inner_scopes_inner_resource._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_roles_inner_scopes_inner_resource(
                                    id = '0', 
                                    name = '0', 
                                    indicator = '0', 
                                    is_default = True, 
                                    access_token_ttl = 1.337, ), )
                            ], )
                    ],
                organizations = [
                    py_logto.models._api_applications__application_id__user_consent_scopes_get_200_response_organization_scopes_inner._api_applications__applicationId__user_consent_scopes_get_200_response_organizationScopes_inner(
                        id = '0', 
                        name = '0', 
                        description = '', )
                    ],
                organization_roles = [
                    py_logto.models._api_configs_jwt_customizer__token_type_path__get_200_response_one_of_context_sample_user_organization_roles_inner._api_configs_jwt_customizer__tokenTypePath__get_200_response_oneOf_contextSample_user_organizationRoles_inner(
                        organization_id = '', 
                        role_id = '', 
                        role_name = '', )
                    ]
            )
        else:
            return ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser(
        )
        """

    def testApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser(self):
        """Test ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
